import streamlit as st
from utils import generate_script

st.title("🎬 動画スクリプト作成ツール")

with st.sidebar:
    openai_api_key = st.text_input("OpenAI APIキーを入力してください：", type="password")
    st.markdown("[OpenAI APIキーを取得](https://platform.openai.com/account/api-keys)")

subject = st.text_input("💡 動画のテーマを入力してください")
video_length = st.number_input("⏱️ 動画のおおよその長さを入力してください（単位：分）", min_value=0.1, step=0.1)
creativity = st.slider("✨ 動画スクリプトの創造性を設定してください（数値が小さいほど厳密になり、大きいほど多様性が増す）",
                       min_value=0.0, max_value=1.0, value=0.2, step=0.1)
submit = st.button("スクリプトを生成")

if submit and not openai_api_key:
    st.info("OpenAI APIキーを入力してください")
    st.stop()
if submit and not subject:
    st.info("動画のテーマを入力してください")
    st.stop()
if submit and not video_length >= 0.1:
    st.info("動画の長さは0.1分以上にしてください")
    st.stop()
if submit:
    with st.spinner("AIが考えています。しばらくお待ちください..."):
        search_result, title, script = generate_script(subject, video_length, creativity, openai_api_key)
    st.success("動画スクリプトが生成されました！")
    st.subheader("🔥 タイトル：")
    st.write(title)
    st.subheader("📝 動画スクリプト：")
    st.write(script)
    with st.expander("Wikipediaの検索結果 👀"):
        st.info(search_result)
