from langchain.prompts import ChatPromptTemplate
from langchain_openai import ChatOpenAI
from langchain_community.utilities import WikipediaAPIWrapper

import os

def generate_script(subject, video_length, creativity, api_key):
    title_template = ChatPromptTemplate.from_messages(
        [
            ("human", "'{subject}' というテーマの動画の魅力的なタイトルを考えてください")
        ]
    )
    script_template = ChatPromptTemplate.from_messages(
        [
            ("human",
             """あなたは短尺動画チャンネルのクリエイターです。以下のタイトルと関連情報に基づいて、短尺動画の台本を書いてください。
                動画タイトル：{title}
                動画の長さ：{duration} 分
                生成する台本の長さは、動画の長さにできるだけ合うようにしてください。
                【台本の構成】
                冒頭：視聴者の注意を引く
                中盤：役立つ情報を提供
                結末：驚きの要素を用意
                また、台本の表現はできるだけ軽快で面白く、若者を引きつけるスタイルにしてください。
                台本の内容は、以下のWikipedia検索結果を参考にすることができますが、あくまで参考として関連する部分のみ使用し、関係のない情報は無視してください：
             ```{wikipedia_search}```""")
        ]
    )

    model = ChatOpenAI(openai_api_key=api_key, temperature=creativity)

    title_chain = title_template | model
    script_chain = script_template | model

    title = title_chain.invoke({"subject": subject}).content

    search = WikipediaAPIWrapper(lang="jp")
    search_result = search.run(subject)

    script = script_chain.invoke({"title": title, "duration": video_length,
                                  "wikipedia_search": search_result}).content

    return search_result, title, script

# print(generate_script("LLM関連 soraモデル", 1, 0.7, os.getenv("OPENAI_API_KEY")))